@@ -19,31 +19,33 @@ import grpc
 from cakework import cakework_pb2
 from cakework import cakework_pb2_grpc
 import json
-import importlib
-# import os
-import time
+import os
 import threading
 import requests
 import logging
-import http.client
-from cakework import auth
-import os
+from dotenv import load_dotenv
 
 logging.basicConfig(level=logging.INFO)
 
+def get_token(context):
+    metadict = dict(context.invocation_metadata())
+    authorization = metadict['authorization']
+    split = authorization.split(' ')
+    return split[1]
+
 class Cakework(cakework_pb2_grpc.CakeworkServicer):
     def __init__(self, user_activity, local=False):
+        load_dotenv()
         self.user_activity = user_activity
         self.local = local
         if self.local:
             self.frontend_url = "http://localhost:8080"
         else:
-            self.frontend_url = "https://cakework-frontend.fly.dev"
+            self.frontend_url = os.getenv("FRONTEND_URL")
 
     def RunActivity(self, request, context):
-        # update to in progress
+        token = get_token(context)
         scope = "update:status update:result"
-        token = auth.get_token("l2OCkl1RIrWgYwaHeH394C0bXKJRIucI", "aYUDERY08rNhciuebW5rpShcU_KmcyY-RK-A55-ltkSmt-1mvAfAcJdVTsZDEBRh", scope) # TODO remove this from open source code
         headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
         response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": request.userId, "app": request.app, "requestId": request.requestId, "status": "IN_PROGRESS"}, headers=headers)
         # TODO check the response
@@ -69,6 +71,7 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
             response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "result": json.dumps(res)}, headers=headers)
             # TODO check the response
             response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "SUCCEEDED"}, headers=headers)
+
         except Exception as e:
             logging.exception("Error occurred while running task", exc_info=True)
             # logging.info(e)
@@ -76,8 +79,9 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
             # TODO: handle case if updating the status in the db failed; then user may keep polling forever
             return cakework_pb2.Reply(result=None)
         finally:
-            print("Finally; os.exiting")
+            logging.info("Request complete, exiting vm")
             os._exit(1)
+
         # Q: who are we returning to here? instead of returning, we can just write this to the database. or emit a message and have the poller be in charge of writing to db
         return cakework_pb2.Reply(result=json.dumps(res))
 
@@ -88,8 +92,6 @@ def serve():
     server.add_insecure_port('[::]:' + port)
     server.start()
     logging.info("Server started, listening on " + port)
-    # TODO delete!!
-    sys.exit("Exiting as soon as spun up")
     server.wait_for_termination()
 
 if __name__ == '__main__':
